==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/SegmentsResponse.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class SegmentsResponse(
    item: Iterable[zio.aws.pinpoint.model.SegmentResponse],
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.SegmentsResponse = {
    import SegmentsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
      .builder()
      .item(item.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.SegmentsResponse.ReadOnly =
    zio.aws.pinpoint.model.SegmentsResponse.wrap(buildAwsValue())
}
object SegmentsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.SegmentsResponse =
      zio.aws.pinpoint.model.SegmentsResponse(
        item.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def item: List[zio.aws.pinpoint.model.SegmentResponse.ReadOnly]
    def nextToken: Option[__string]
    def getItem: ZIO[Any, Nothing, List[
      zio.aws.pinpoint.model.SegmentResponse.ReadOnly
    ]] = ZIO.succeed(item)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
  ) extends zio.aws.pinpoint.model.SegmentsResponse.ReadOnly {
    override val item: List[zio.aws.pinpoint.model.SegmentResponse.ReadOnly] =
      impl
        .item()
        .asScala
        .map { item =>
          zio.aws.pinpoint.model.SegmentResponse.wrap(item)
        }
        .toList
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
  ): zio.aws.pinpoint.model.SegmentsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/SegmentsResponse.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SegmentsResponse(
    item: Iterable[zio.aws.pinpoint.model.SegmentResponse],
    nextToken: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.SegmentsResponse = {
    import SegmentsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
      .builder()
      .item(item.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.SegmentsResponse.ReadOnly =
    zio.aws.pinpoint.model.SegmentsResponse.wrap(buildAwsValue())
}
object SegmentsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.SegmentsResponse =
      zio.aws.pinpoint.model.SegmentsResponse(
        item.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def item: List[zio.aws.pinpoint.model.SegmentResponse.ReadOnly]
    def nextToken: Optional[__string]
    def getItem: ZIO[Any, Nothing, List[
      zio.aws.pinpoint.model.SegmentResponse.ReadOnly
    ]] = ZIO.succeed(item)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
  ) extends zio.aws.pinpoint.model.SegmentsResponse.ReadOnly {
    override val item: List[zio.aws.pinpoint.model.SegmentResponse.ReadOnly] =
      impl
        .item()
        .asScala
        .map { item =>
          zio.aws.pinpoint.model.SegmentResponse.wrap(item)
        }
        .toList
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.SegmentsResponse
  ): zio.aws.pinpoint.model.SegmentsResponse.ReadOnly = new Wrapper(impl)
}
